Welcome to Orange3 Bioinformatics Documentation
================================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/databases_update.md
   widgets/geo_data_sets.md
   widgets/dicty_express.md
   widgets/gene_name_matcher.md
   widgets/differential_expression.md
   widgets/go_browser.md
   widgets/kegg_pathways.md
   widgets/gene_set_enrichment.md
   widgets/cluster_analysis.md



Scripting Reference
-------------------

.. toctree::
   :maxdepth: 1

   scripting_references/ncbi_taxonomy
   scripting_references/ncbi_gene
   scripting_references/geo
   scripting_references/go
   scripting_references/geneset
   scripting_references/dicty_phenotypes
   scripting_references/kegg
   scripting_references/resolwe
